==> oh-my-posh-7.69.0.tar.gz: oh-my-posh-7.69.0/README.md <==
<!-- markdownlint-disable -->
<p align="center">
  <img
    width="400"
    src="https://raw.githubusercontent.com/jandedobbeleer/oh-my-posh/main/docs/static/img/logo.png"
    alt="Oh My Posh – Prompt theme engine for any shell"
  />
</p>
<!-- markdownlint-enable -->
<!-- markdownlint-disable first-header-h1 -->

![Release Status][release-status]

[![Release][release-badge]][release]
[![Documentation][docs-badge]][docs]

[![PS Gallery][psgallery-badge]][powershell-gallery]
![GitHub Downloads][gh-downloads]

![Twitter][twitter]

This repo was made with love using GitKraken.

[![GitKraken shield][kraken]][kraken-ref]

What started as the offspring of [oh-my-posh2][oh-my-posh2] for PowerShell resulted in a cross platform,
highly customizable and extensible prompt theme engine. After 4 years of working on oh-my-posh,
a modern and more efficient tool was needed to suit my personal needs.

## ❤ Support ❤

[![Swag][swag-badge]][swag] - Show your love with a t-shirt!

[![GitHub][github-badge]][github-sponsors] - One time support, or a recurring donation?

[![Ko-Fi][kofi-badge]][kofi] - No coffee, no code.

## Features

* Shell and platform agnostic
* Easily configurable
* The **most** configurable prompt utility
* Fast
* Secondary prompt
* Right prompt
* Transient prompt

## Documentation

[![Documentation][docs-badge]][docs]

## Thanks

* [Chris Benti][chrisbenti-psconfig] for providing the first influence to start oh-my-posh
* [Keith Dahlby][keithdahlby-poshgit] for creating posh-git and making life more enjoyable
* [Robby Russel][oh-my-zsh] for creating oh-my-zsh, without him this would probably not be here
* [Janne Mareike Koschinski][justjanne] for providing information on how to get certain information
using Go (and the amazing [README][powerline-go])
* [Starship][starship] for creating an amazing way to initialize the prompt

[release-status]: https://img.shields.io/github/workflow/status/jandedobbeleer/oh-my-posh/Release?label=Build
[psgallery-badge]: https://img.shields.io/powershellgallery/dt/oh-my-posh?color=pink&label=PowerShell%20Downloads
[powershell-gallery]: https://www.powershellgallery.com/packages/oh-my-posh/
[gh-downloads]: https://img.shields.io/github/downloads/jandedobbeleer/oh-my-posh/total?color=pink&label=GitHub%20Downloads
[twitter]: https://shields.io/twitter/follow/jandedobbeleer?label=Follow
[kraken]: https://img.shields.io/badge/GitKraken-Legendary%20Git%20Tools-teal?style=plastic&logo=gitkraken
[kraken-ref]: https://www.gitkraken.com/invite/nQmDPR9D
[oh-my-posh2]: https://github.com/JanDeDobbeleer/oh-my-posh2
[swag-badge]: https://img.shields.io/badge/Swag-Get%20some!-blue
[swag]: https://swag.ohmyposh.dev
[github-badge]: https://img.shields.io/badge/-Sponsor-fafbfc?logo=GitHub%20Sponsors
[github-sponsors]: https://github.com/sponsors/JanDeDobbeleer
[kofi-badge]: https://img.shields.io/badge/Ko--fi-Buy%20me%20a%20coffee!-%2346b798.svg
[kofi]: https://ko-fi.com/jandedobbeleer
[docs-badge]: https://img.shields.io/badge/Docs-ohmyposh.dev-blue
[docs]: https://ohmyposh.dev
[release-badge]: https://img.shields.io/github/v/release/jandedobbeleer/oh-my-posh?label=Release
[release]: https://github.com/JanDeDobbeleer/oh-my-posh/releases/latest
[chrisbenti-psconfig]: https://github.com/chrisbenti/PS-Config
[keithdahlby-poshgit]: https://github.com/dahlbyk/posh-git
[oh-my-zsh]: https://github.com/robbyrussell/oh-my-zsh
[justjanne]: https://github.com/justjanne
[powerline-go]: https://github.com/justjanne/powerline-go
[starship]: https://github.com/starship/starship/blob/master/src/init/mod.rs

==> oh-my-posh-7.85.2.tar.gz: oh-my-posh-7.85.2/README.md <==
<!-- markdownlint-disable -->
<p align="center">
  <img
    width="400"
    src="https://raw.githubusercontent.com/jandedobbeleer/oh-my-posh/main/website/static/img/logo.png"
    alt="Oh My Posh – Prompt theme engine for any shell"
  />
</p>
<!-- markdownlint-enable -->
<!-- markdownlint-disable first-header-h1 -->

![Release Status][release-status]

[![Release][release-badge]][release]
[![Documentation][docs-badge]][docs]

[![PS Gallery][psgallery-badge]][powershell-gallery]
![GitHub Downloads][gh-downloads]

![Twitter][twitter]

This repo was made with love using GitKraken.

[![GitKraken shield][kraken]][kraken-ref]

What started as the offspring of [oh-my-posh2][oh-my-posh2] for PowerShell resulted in a cross platform,
highly customizable and extensible prompt theme engine. After 4 years of working on oh-my-posh,
a modern and more efficient tool was needed to suit my personal needs.

## ❤ Support ❤

[![Swag][swag-badge]][swag] - Show your love with a t-shirt!

[![GitHub][github-badge]][github-sponsors] - One time support, or a recurring donation?

[![Ko-Fi][kofi-badge]][kofi] - No coffee, no code.

## Features

* Shell and platform agnostic
* Easily configurable
* The **most** configurable prompt utility
* Fast
* Secondary prompt
* Right prompt
* Transient prompt

## Documentation

[![Documentation][docs-badge]][docs]

## Thanks

* [Chris Benti][chrisbenti-psconfig] for providing the first influence to start oh-my-posh
* [Keith Dahlby][keithdahlby-poshgit] for creating posh-git and making life more enjoyable
* [Robby Russel][oh-my-zsh] for creating oh-my-zsh, without him this would probably not be here
* [Janne Mareike Koschinski][justjanne] for providing information on how to get certain information
using Go (and the amazing [README][powerline-go])
* [Starship][starship] for creating an amazing way to initialize the prompt

[release-status]: https://img.shields.io/github/workflow/status/jandedobbeleer/oh-my-posh/Release?label=Build
[psgallery-badge]: https://img.shields.io/powershellgallery/dt/oh-my-posh?color=pink&label=PowerShell%20Downloads
[powershell-gallery]: https://www.powershellgallery.com/packages/oh-my-posh/
[gh-downloads]: https://img.shields.io/github/downloads/jandedobbeleer/oh-my-posh/total?color=pink&label=GitHub%20Downloads
[twitter]: https://shields.io/twitter/follow/jandedobbeleer?label=Follow
[kraken]: https://img.shields.io/badge/GitKraken-Legendary%20Git%20Tools-teal?style=plastic&logo=gitkraken
[kraken-ref]: https://www.gitkraken.com/invite/nQmDPR9D
[oh-my-posh2]: https://github.com/JanDeDobbeleer/oh-my-posh2
[swag-badge]: https://img.shields.io/badge/Swag-Get%20some!-blue
[swag]: https://swag.ohmyposh.dev
[github-badge]: https://img.shields.io/badge/-Sponsor-fafbfc?logo=GitHub%20Sponsors
[github-sponsors]: https://github.com/sponsors/JanDeDobbeleer
[kofi-badge]: https://img.shields.io/badge/Ko--fi-Buy%20me%20a%20coffee!-%2346b798.svg
[kofi]: https://ko-fi.com/jandedobbeleer
[docs-badge]: https://img.shields.io/badge/Docs-ohmyposh.dev-blue
[docs]: https://ohmyposh.dev
[release-badge]: https://img.shields.io/github/v/release/jandedobbeleer/oh-my-posh?label=Release
[release]: https://github.com/JanDeDobbeleer/oh-my-posh/releases/latest
[chrisbenti-psconfig]: https://github.com/chrisbenti/PS-Config
[keithdahlby-poshgit]: https://github.com/dahlbyk/posh-git
[oh-my-zsh]: https://github.com/robbyrussell/oh-my-zsh
[justjanne]: https://github.com/justjanne
[powerline-go]: https://github.com/justjanne/powerline-go
[starship]: https://github.com/starship/starship/blob/master/src/init/mod.rs
